// Copyright 2019 Sorint.lab
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied
// See the License for the specific language governing permissions and
// limitations under the License.

package cmd

import (
	"github.com/spf13/cobra"
)

var cmdProjectGroupSecretCreate = &cobra.Command{
	Use:   "create",
	Short: "create a project group secret",
	Run: func(cmd *cobra.Command, args []string) {
		if err := secretCreate(cmd, "projectgroup", args); err != nil {
			log.Fatalf("err: %v", err)
		}
	},
}

func init() {
	flags := cmdProjectGroupSecretCreate.Flags()

	flags.StringVar(&secretCreateOpts.parentRef, "projectgroup", "", "project group id or full path")
	flags.StringVarP(&secretCreateOpts.name, "name", "n", "", "secret name")
	flags.StringVar(&secretCreateOpts.data, "data", "", "json map of secret data")

	cmdProjectGroupSecretCreate.MarkFlagRequired("project")
	cmdProjectGroupSecretCreate.MarkFlagRequired("name")
	cmdProjectGroupSecretCreate.MarkFlagRequired("data")

	cmdProjectGroupSecret.AddCommand(cmdProjectGroupSecretCreate)
}
